options nodate nonumber ; *These are options for better graphs;
run; 
libname ch4 "."; *The "." sets the default directory to be the current SAS folder;
*The directory can be changed by clicking on the disk icon on the lower right hand corner of the SAS GUI;
*Make sure that the time.sas7bdat dataset is copied to this folder;
run;

*CONTROL GROUP;
data timec;
set ch4.time;
if treatment = 0;
run;

*This procedure produces the upper half of Figure 4.2;
ods graphics on/antialiasmax=40200 height=9in width=9in;
ods pdf style=journal dpi=300 file="C:\Users\Niall\Dropbox\NIALL1\MET\DB\Chapter 4 Time\c4data\raw-ctl.pdf";
run;
title1 "Control Group";
proc sgpanel data=timec CYCLEATTRS noautolegend;
 panelby id/columns=5 rows=5 novarname;
 series x=time y=intimacy /LINEATTRS = (pattern = 1 color = black thickness=1);
 scatter x=time y=intimacy /MARKERATTRS = (symbol=x color = black);
 rowaxis min=0 max=8 label='Intimacy';
 colaxis label='Time in Weeks';
run;
ods pdf close;
ods graphics off;
run;

*TREATMENT GROUP;
data timet;
set ch4.time;
if treatment = 1;
run;

*This procedure produces the lower half of Figure 4.2;
ods graphics on/antialiasmax=40200 height=9in width=9in;
ods pdf style=journal dpi=300 file="C:\Users\Niall\Dropbox\NIALL1\MET\DB\Chapter 4 Time\c4data\raw-trt.pdf";
run;
title1 "Treatment Group";
proc sgpanel data=timet CYCLEATTRS noautolegend;
 panelby id/columns=5 rows=5 novarname;
 series x=time y=intimacy /LINEATTRS = (pattern = 1 color = black thickness=1);
 scatter x=time y=intimacy /MARKERATTRS = (symbol=x color = black);
 rowaxis min=0 max=8 label='Intimacy';
 colaxis label='Time in Weeks';
run;
ods pdf close;
ods graphics off;
run;


*This produces output used in Table 4.1, Table 4.2, and Table 1 of the Chapter 5 write-up section;
proc mixed covtest data=ch4.time method=reml cl;
class id time;
model intimacy=time01 treatment time01*treatment/solution cl ddf=48,48,48,48 outp=tpred outpm=tpredm residual;
random int time01/subject=id type=un s g gcorr;
repeated time/subject=id type=ar(1);
ods exclude SolutionR;
ods output SolutionR = randpred;
run;

*Compare Intimacy model to same model using Mplus: use ML, drop ar(1);
proc mixed covtest data=ch4.intimacy method=ml cl;
class id time;
model intimacy=time01 treatment time01*treatment/solution cl ddf=48,48,48,48 outp=intp outpm=intpm residual;
random int time01/subject=id type=un s g gcorr;
repeated time/subject=id; *type=ar(1);
ods exclude SolutionR;
run;


*Predicted values for control group;
data tpredc;
set tpred;
if treatment=0;
run;

*This procedure produces the upper half of Figure 4.4;
ods graphics on/antialiasmax=40200 height=9in width=9in;
ods pdf style=journal dpi=300 file="C:\Users\Niall\Dropbox\NIALL1\MET\DB\Chapter 4 Time\c4data\tpred-c.pdf";
run;
title1 "Control Group";
proc sgpanel data=tpredc CYCLEATTRS noautolegend;
 panelby id/columns=5 rows=5 novarname;
 series x=time y=pred /LINEATTRS = (pattern = 1 color = black thickness=3);
 series x=time y=intimacy /LINEATTRS = (pattern = 1 color = black thickness=1);
 scatter x=time y=intimacy /MARKERATTRS = (symbol=x color = black);
 rowaxis min=0 max=8 label='Intimacy';
 colaxis label='Time in Weeks';
run;
ods pdf close;
run;
ods graphics off;
run;

*Predicted values for treatment group;
data tpredt;
set tpred;
if treatment=1;
run;

*This procedure produces the lower half of Figure 4.4;
ods graphics on/antialiasmax=40200 height=9in width=9in;
ods pdf style=journal dpi=300 file="C:\Users\Niall\Dropbox\NIALL1\MET\DB\Chapter 4 Time\c4data\tpred-t.pdf";
run;
title1 "Treatment Group";
proc sgpanel data=tpredt CYCLEATTRS noautolegend;
 panelby id/columns=5 rows=5 novarname;
 series x=time y=pred /LINEATTRS = (pattern = 1 color = black thickness=3);
 series x=time y=intimacy /LINEATTRS = (pattern = 1 color = black thickness=1);
 scatter x=time y=intimacy /MARKERATTRS = (symbol=x color = black);
 rowaxis min=0 max=8 label='Intimacy';
 colaxis label='Time in Weeks';
run;
ods pdf close;
run;
ods graphics off;
run;

*Spaghetti plots below are used in Figure 4.5 and Figure 1 of the write-up section for Chapter 4;
data tpredm1;
set tpredm;
predm=pred;
keep id time predm;
run;
 
data tpred1;
merge tpred tpredm1;
by id time;
if treatment=0 then trtcat= "Control";
if treatment=1 then trtcat= "Treat";
run;

title1;
ods pdf style=journal dpi=300 file="C:\Users\Niall\Dropbox\NIALL1\MET\DB\Chapter 4 Time\c4data\spag-time.pdf";
ods graphics on/antialiasmax=40200 height=8in width=10in;
run;
*Two-panel spaghetti plot;
proc sgpanel data=tpred1 noautolegend; *CYCLEATTRS ;
panelby trtcat/novarname;
series x=time y=pred/group=id LINEATTRS = (pattern = 1 color = black thickness=2);
series x=time y=predm/ LINEATTRS = (pattern = 1 color = black thickness=9);
rowaxis min=1 max=7 label='Intimacy';
colaxis label='Time in Weeks';
run;
ods pdf close;
run;
ods graphics off;
run;


*This code below produces the upper half of Figure 2 of the Chapter 4 write-up section;
*Select subjects based on their approximate control group slope percentiles (5, 25, 50, 75, 95);
data slopec5;
set randpred;
if effect = "time01";
if id = 4 or id = 8 or id = 12 or id = 15 or id = 22;
slope=estimate + 0.74;
keep id slope;
run;

*Select the same subjects from the predicted values dataset;
data tempc5;
set tpredc;
if id = 4 or id = 8 or id = 12 or id = 15 or id = 22;
run;

*Merge the two datasets;
data tpredc5;
merge tempc5 slopec5;
by id;
run;

*Sort by slope value;
proc sort data=tpredc5;
by slope;
run;

ods graphics on/antialiasmax=40200 height=2in width=9in;
ods pdf style=journal dpi=300 file="C:\Users\Niall\Dropbox\NIALL1\MET\DB\Chapter 4 Time\c4data\tpredc5.pdf";
run;
title1 "Control Group";
proc sgpanel data=tpredc5 CYCLEATTRS noautolegend;
 panelby slope/columns=5 rows=1 novarname;
 series x=time y=pred /LINEATTRS = (pattern = 1 color = black thickness=3);
 series x=time y=intimacy /LINEATTRS = (pattern = 1 color = black thickness=1);
 scatter x=time y=intimacy /MARKERATTRS = (symbol=x color = black);
 rowaxis min=0 max=8 label='Intimacy';
 colaxis label='Time in Weeks';
run;
ods pdf close;
run;
ods graphics off;
run;


*This procedure produces the lower half of Figure 2 of the Chapter 4 write-up section;
*Select subjects based on their approximate treatment group slope percentiles (5, 25, 50, 75, 95);
data slopet5;
set randpred;
if effect = "time01";
if id = 26 or id = 37 or id = 46 or id = 49 or id = 50;
slope=estimate +  0.74 + 0.9214;
keep id slope;
run;

*Select the same subjects from the predicted values dataset;
data tempt5;
set tpredt;
if id = 26 or id = 37 or id = 46 or id = 49 or id = 50;
run;

*Merge the two datasets;
data tpredt5;
merge tempt5 slopet5;
by id;
run;

*Sort by slope value;
proc sort data=tpredt5;
by slope;
run;


*FITTED DATA for five persons: Panel plots of fitted dv and raw data;
ods graphics on/antialiasmax=40200 height=2in width=9in;
ods pdf style=journal dpi=300 file="C:\Users\Niall\Dropbox\NIALL1\MET\DB\Chapter 4 Time\c4data\tpredt5.pdf";
run;
title1 "Treatment Group";
proc sgpanel data=tpredt5 CYCLEATTRS noautolegend;
 panelby slope/columns=5 rows=1 novarname;
 series x=time y=pred /LINEATTRS = (pattern = 1 color = black thickness=3);
 series x=time y=intimacy /LINEATTRS = (pattern = 1 color = black thickness=1);
 scatter x=time y=intimacy /MARKERATTRS = (symbol=x color = black);
 rowaxis min=0 max=8 label='Intimacy';
 colaxis label='Time in Weeks';
run;
ods pdf close;
run;
ods graphics off;
run;
